@@ -377,7 +377,7 @@ def getAnnoTools(toolPath):
     with open(toolPath+'/annoTools.txt') as f:
         file =  f.readlines()
         if '#checked' not in ''.join(file):
-            sys.exit('Annotation tools not ready. Please run setupFAS first!')
+            sys.exit('Annotation tools not ready. Please run fas.setup first!')
         else:
             for tool in file:
                 if ('#' not in tool) and (len(tool) > 1):
